/*
-------------------------------------------------------------------------------
    This file is a part of the Vst Preset Generator
    Copyright (C) 2007  Francois Mazen

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-------------------------------------------------------------------------------
  Name: paramwidget.cpp
  Author: Francois Mazen
  Date: 28/05/07 16:25
  Description: a paramwidget is a widget which contains bouton, label and 
               functions, in order to get the random parameters.
-------------------------------------------------------------------------------
*/

#include <QtGui>
#include "paramwidget.h"


//-----------------------------------------------------------------------------
ParamWidget::ParamWidget(qint32 num): QWidget()
{

       container = new QHBoxLayout(this);
       
       QString charbuffer;
       charbuffer.setNum(num);
       charbuffer.prepend( tr("Parameter #"));
       lblParam = new QLabel(charbuffer);
       lblValue = new QLabel(tr("value:"),this);
       lblValue->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
       lblMin = new QLabel(tr("min:"),this);
       lblMin->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
       lblMax = new QLabel(tr("max:"),this);
       lblMax->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
       
       rbtnConstant = new QRadioButton(tr("Constant"),this);
       rbtnRandom = new QRadioButton(tr("Random"),this);
       
       spbxValue = new QDoubleSpinBox(this);
       spbxValue->setRange(0,1);
       spbxValue->setSingleStep(0.1); 
       spbxMin = new QDoubleSpinBox(this);
       spbxMin->setRange(0,1);
       spbxMin->setSingleStep(0.1); 
       spbxMax = new QDoubleSpinBox(this);
       spbxMax->setRange(0,1);
       spbxMax->setSingleStep(0.1); 
       spbxMax->setValue(1);
       
       container->addWidget(lblParam);
       container->addWidget(rbtnConstant);
       container->addWidget(lblValue);
       container->addWidget(spbxValue);
       container->addWidget(rbtnRandom);
       container->addWidget(lblMin);
       container->addWidget(spbxMin);
       container->addWidget(lblMax);
       container->addWidget(spbxMax);
       
       setLayout(container);
       
       connect(rbtnConstant, SIGNAL(toggled(bool)), spbxValue, SLOT(setEnabled ( bool )));
       connect(rbtnConstant, SIGNAL(toggled(bool)), lblValue, SLOT(setEnabled ( bool )));
       connect(rbtnRandom, SIGNAL(toggled(bool)), spbxMin, SLOT(setEnabled ( bool )));
       connect(rbtnRandom, SIGNAL(toggled(bool)), spbxMax, SLOT(setEnabled ( bool )));
       connect(rbtnRandom, SIGNAL(toggled(bool)), lblMin, SLOT(setEnabled ( bool )));
       connect(rbtnRandom, SIGNAL(toggled(bool)), lblMax, SLOT(setEnabled ( bool )));
       
       connect(spbxMin, SIGNAL(valueChanged(double)), this, SLOT(checkSpinBox()));
       connect(spbxMax, SIGNAL(valueChanged(double)), this, SLOT(checkSpinBox()));
       
       rbtnConstant->setChecked(true);
       rbtnRandom->setChecked(true);
       
       
}

//-----------------------------------------------------------------------------

float ParamWidget::getMin()
{
      if(rbtnConstant->isChecked())
             return ((float)spbxValue->value());
             
      return spbxMin->value();
      
}

//-----------------------------------------------------------------------------

float ParamWidget::getMax()
{
      if(rbtnConstant->isChecked())
             return ((float)spbxValue->value());
             
      return spbxMax->value();
      
}

//-----------------------------------------------------------------------------
void ParamWidget::checkSpinBox()
{
      if(spbxMin->value() > spbxMax->value())
      {
             spbxMax->setValue(spbxMin->value());
      }
      if(spbxMax->value() < spbxMin->value())
      {
             spbxMin->setValue(spbxMax->value());
      }
}
